@@ -30,6 +30,8 @@
 
 use warnings;
 use strict;
+# Good modern Perl practice and some of our features warrant this:
+BEGIN { @INC = grep {$_ ne '.'} @INC };
 
 # If you can't update /etc/services to contain an entry for 'sieve' and you're
 # not using 4190 (specified in RFC 5804) and you're not publishing an SRV
@@ -90,7 +92,7 @@ my $OPENSSL_COMMAND = 'openssl';
 # ######################################################################
 # No user-serviceable parts below
 
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 
 use Authen::SASL 2.11 qw(Perl);
 # 2.11: first version with non-broken DIGEST-MD5
@@ -250,7 +252,9 @@ GetOptions(
 	"edit"		=> sub { $action = 'edit' },
 	"exec|e=s"	=> sub { $execscript = $_[1]; $action='command-loop' },
 	# then administrivia
-	'help|?'	=> sub { pod2usage(0) },
+	'help|?'	=> sub { pod2usage(-exitstatus => 0,
+				 -verbose => 99, -sections => "SYNOPSIS",
+				 -message => "Use --man for more help text\n") },
 	'man'		=> sub { pod2usage(-exitstatus => 0, -verbose => 2) },
 	'version'	=> \$opt_version_req, # --version --debug should work
 ) or pod2usage(2);
@@ -2535,6 +2539,15 @@ See a lot of what's happening under the covers:
     [ snip 30 or so lines ]
     >
 
+Use B<--passwordfd> to supply the password using stdio instead of argv or
+environ, where it might show up in process listings; this example assumes a
+shell with "here-strings", such as zsh or bash:
+
+    $   password='...'
+    $ sieve-connect --authmech digest-md5 --passwordfd=5 5<<<"$password"
+    ReadLine support enabled.
+    >
+
 =head1 ENVIRONMENT
 
 C<$IMAP_SERVER> for a default IMAP server.
